#NoEnv ; Avoid checking empty variables for environment variables
#Warn ; Enable warnings to assist with detecting common errors
#NoTrayIcon ; Disable the tray icon of the script
SendMode, Input ; The method for sending keystrokes and mouse clicks
SetWorkingDir, %A_ScriptDir% ; Set the working directory of the script
#SingleInstance


Global ProgramName := "EZWinFR"
Global ProgramPath := A_ScriptDir . "" . ProgramName
Global ProgramDate := "07 Jul 2023"
Global ExeName := "WinFR.exe"
Global ExePath := A_ScriptDir . "\" . ExeName
Global IniPath := A_ScriptDir . "\WinFR-Help.txt"
Global RecoveryDir := ""
Global WinWidth := 900
Global WinHeight := 600
Global EditWidth := WinWidth - 50
Global CmdLine := ""
Global CmdLineDef := "winfr command line displayed here, syntax:`nwinfr source-drive: destination-drive: [/mode] [/switches]"

If Not FileExist(ExePath)
{
	MsgBox, 16,% "Error", % ExeName . " does not exist in current directory. Aborting", 2
	ExitApp, 1
}

If Not A_IsAdmin
{
	MsgBox, 16,% "Error", % ExeName . " needs to be run as admin. Aborting", 2
	ExitApp, 1
}

DriveList := ""
DriveLabel := ""
DriveArray := []
DropDownList := ""
DriveGet, DriveList, List
DriveArray := StrSplit(DriveList)

For Index, Value In DriveArray
{
	DriveGet, DriveLabel, Label, % Value . ":"
    DropDownList .= Value . " [" . DriveLabel . "]|" 
}
DropDownList := RTrim(DropDownList, "|")

Gui, Font, s11 c000000, Consolas
Gui, Color, f0f0f0

Gui, Font, Bold
Gui, Add, Text, w%WinWidth% Center, EZ WINDOWS FILE RECOVERY
Gui, Font, Normal

Gui, Add, Text,xM+10 y+20, 1. Select the source drive to scan for deleted files.
Global SourceDrive := ""
Global SourceDrive2 := ""
Gui, Add, DropDownList, vSourceDrive, %DropDownList%

Gui, Add, Text, y+20, 2. Enter the name of the file/folder (wildcards allowed, trailing \ for folder) to recover.
Global Filename := ""
Gui, Add, Edit, w%EditWidth% vFilename

Gui, Add, Text,y+20, 3. Select the destination drive to save the recovered files (in folder Recovery_<date_time>).
Global DestDrive := ""
Global DestDrive2 := ""
Gui, Add, DropDownList, vDestDrive, %DropDownList%

Gui, Add, Text,y+20, 4. Select the recovery mode.
Global Mode := ""
Gui, Add, DropDownList, vMode, % "regular||extensive"

Gui, Add, Text,y+20, 5. Click 'Recover Files'.
Gui, Add, Button, w200 gRecoverFile, Recover Files

Gui, Add, Edit, y+20 w%EditWidth% vCmdLine Border r5, % CmdLineDef
GuiControl, Disable, CmdLine

Gui, Add, Button, y+30 gShowHelp, Display help file

Gui, Add, StatusBar

If Not FileExist(IniPath)
{
	SB_SetText("Cannot find help file '" . IniPath . "' in current directory.")
}


Gui, Show, % "w" . WinWidth "h" . WinHeight, % ProgramName . "    " . ProgramDate

Return

GuiClose:
ExitApp

RecoverFile()
{
	Gui, Submit, NoHide
	
	SourceDrive2 := SubStr(SourceDrive, 1, 1) . ":"
	DestDrive2 := SubStr(DestDrive, 1, 1) . ":"
	
	If (SourceDrive2 = "" Or DestDrive2 = "")
	{
		MsgBox, 16,% "Error", % "Select source (1) and destination (3) drives.", 3
		Return True
	}
	If (SourceDrive2 = DestDrive2)
	{
		MsgBox, 16,% "Error", % "Source drive (1) cannot be same as destination (3) drive.", 3
		Return True
	}
	Filename = %Filename%  	;;; AutoTrim OR use var3 := RegExReplace(var3, "(.*[^\s]).*$","$1")
	If (StrLen(Filename) < 1)
	{
		MsgBox, 16,% "Error", % "Enter the filename (2).", 3
		Return True
	}
	
;;;    SB_SetText("Selected option: " . SourceDrive2 . " and " . DestDrive2 . " mode " . Mode . " Filename " . Filename)
		
	CmdLine := """" . ExePath . """  " . SourceDrive2 . "  " .  DestDrive2 .  "  /n """ . Filename . """"
	GuiControl, Text, CmdLine, %CmdLine%
;;;    SB_SetText(CmdLine)

	GuiControl, Enable, CmdLine

	MsgBox, % 4096 + 4, %ProgramName%, % "Run Windows File Recovery ?" . "`n`nCheck (and modify if necessary) the winfr command line below."
	IfMsgBox No
	{
		GuiControl, Text, CmdLine, % CmdLineDef
		GuiControl, Disable, CmdLine
		MsgBox, 16, % ProgramName, % "File recovery cancelled.", 2
		Return True
	}
	
	GuiControlGet, CmdLine,, CmdLine
	GuiControl, Disable, CmdLine
;;;	MsgBox, 16, % ProgramName, % CmdLine

	SB_SetText("Please wait ...")
	Gui, 1: +Disabled
	
	RunWait %ComSpec% /c "%CmdLine%"
	
	Sleep, 1000
	Gui, 1: -Disabled
	SB_SetText("")
	
	WinActivate, %ProgramName%, EZWinFR

	Return False
}

ShowHelp()
{
	Run, % "notepad.exe " . IniPath
}

GuiContextMenu()
{
		
	MsgBox, , About, %ProgramName%  (%ProgramDate%)`nSimple GUI for Windows File Recovery`n`n    - by G B Rao , 7
	return
}





